@@ -834,7 +834,7 @@ wifi_add_menu_item (NMDevice *device,
 		GSList *topmenu_items = NULL;
 		guint32 num_for_toplevel = 5;
 
-		applet_menu_item_add_complex_separator_helper (menu, applet, _("Available"), -1);
+		applet_menu_item_add_complex_separator_helper (menu, applet, _("Available"));
 
 		if (g_slist_length (menu_items) == (num_for_toplevel + 1))
 			num_for_toplevel++;
