@@ -125,10 +125,10 @@ uint_entries_validate (GtkBuilder *builder, const char *fmt, gint max, gboolean
 			if (errno || num < 0 || num > max) {
 				/* FIXME: only sets highlight color? */
 				gdk_rgba_parse (&bgcolor, "red3");
-				gtk_widget_override_background_color (GTK_WIDGET (entry), GTK_STATE_NORMAL, &bgcolor);
+				gtk_widget_override_background_color (GTK_WIDGET (entry), GTK_STATE_FLAG_NORMAL, &bgcolor);
 				valid = FALSE;
 			} else
-				gtk_widget_override_background_color (GTK_WIDGET (entry), GTK_STATE_NORMAL, NULL);
+				gtk_widget_override_background_color (GTK_WIDGET (entry), GTK_STATE_FLAG_NORMAL, NULL);
 
 			total += (guint) num;
 		}
